smartcard.sw.ISO7816_8ErrorChecker.ISO7816_8ErrorChecker

# ``smartcard`.`sw`.`ISO7816_8ErrorChecker`.`ISO7816_8ErrorChecker``

class documentation

`class ISO7816_8ErrorChecker(ErrorChecker):`

View In Hierarchy

ISO7816-8 error checker.

This error checker raises the following exceptions:

- sw1 sw2
- 63 00,c0-cf `WarningProcessingException`
- 65 81 `ExecutionErrorException`
- 66 00,87,88 `SecurityRelatedException`
- 67 00 `CheckingErrorException`
- 68 82,84 `CheckingErrorException`
- 69 82,83,84,85 `CheckingErrorException`
- 6A 81,82,86,88 `CheckingErrorException`

This checker does not raise exceptions on undefined sw1 values, e.g.:

- sw1 sw2
- 62 any
- 6f any

and on undefined sw2 values, e.g.:

- sw1 sw2
- 66 81 82
- 67 any except 00

Use another checker in the error checking chain, e.g., the `ISO7816_4_SW1ErrorChecker` or `ISO7816_4ErrorChecker`, to raise exceptions on these undefined values.

Method | `__call__` | Called to test data, sw1 and sw2 for error.

def __call__(self, data, sw1, sw2):
overrides `smartcard.sw.ErrorChecker.ErrorChecker.__call__`

Called to test data, sw1 and sw2 for error.

Derived classes must raise a `smartcard.sw.SWExceptions` upon error.

Parameters
data | apdu response data
sw1 | apdu data status word 1
sw2 | apdu data status word 2